package com.sun.org.apache.xml.internal.serialize;

import com.sun.org.apache.xerces.internal.utils.ObjectFactory;
import java.util.StringTokenizer;
import com.sun.org.apache.xerces.internal.utils.SecuritySupport;
import java.util.Collections;
import java.util.HashMap;
import java.io.UnsupportedEncodingException;
import java.io.OutputStream;
import java.io.Writer;
import java.util.Map;

public abstract class SerializerFactory
{
    public static final String FactoriesProperty = "com.sun.org.apache.xml.internal.serialize.factories";
    private static final Map<String, SerializerFactory> _factories;
    
    public SerializerFactory() {
    }
    
    public static void registerSerializerFactory(SerializerFactory factory) {
        synchronized (SerializerFactory._factories) {
            String method = factory.getSupportedMethod();
            SerializerFactory._factories.put(method, factory);
        }
    }
    
    public static SerializerFactory getSerializerFactory(String method) {
        return (SerializerFactory)SerializerFactory._factories.get(method);
    }
    
    protected abstract String getSupportedMethod();
    
    public abstract Serializer makeSerializer(OutputFormat p0);
    
    public abstract Serializer makeSerializer(Writer p0, OutputFormat p1);
    
    public abstract Serializer makeSerializer(OutputStream p0, OutputFormat p1) throws UnsupportedEncodingException;
    
    static {
        _factories = Collections.synchronizedMap(new HashMap());
        SerializerFactory factory = new SerializerFactoryImpl("xml");
        registerSerializerFactory(factory);
        factory = new SerializerFactoryImpl("html");
        registerSerializerFactory(factory);
        factory = new SerializerFactoryImpl("xhtml");
        registerSerializerFactory(factory);
        factory = new SerializerFactoryImpl("text");
        registerSerializerFactory(factory);
        String list = SecuritySupport.getSystemProperty("com.sun.org.apache.xml.internal.serialize.factories");
        if (list != null) {
            StringTokenizer token = new StringTokenizer(list, " ;,:");
            while (token.hasMoreTokens()) {
                String className = token.nextToken();
                try {
                    factory = (SerializerFactory)ObjectFactory.newInstance(className, true);
                    if (SerializerFactory._factories.containsKey(factory.getSupportedMethod())) {
                        SerializerFactory._factories.put(factory.getSupportedMethod(), factory);
                    }
                    else {
                        continue;
                    }
                }
                catch (Exception ex) {}
            }
        }
    }
}
